# PyMetarD: METAR Data Downloader
Download parsed METAR data (real-time and historical) from NOAA sites like Aviation Weather Center and Weather.gov.

<p>
    <img src ="https://img.shields.io/badge/platform-windows|linux|macos-yellow.svg"/>
    <img src ="https://img.shields.io/badge/python-3.7|3.8|3.9|3.10|3.11-blue.svg" />
    <img src ="https://img.shields.io/github/actions/workflow/status/ai4time/pymetard/ci.yml?branch=master&label=ci"/>
    <img src ="https://img.shields.io/github/actions/workflow/status/ai4time/pymetard/dist.yaml?label=dist"/>
</p>
